#!/bin/bash

################################################################
# WebLogic-OutSystems: Common utils
################################################################

# WebLogic - OutSystems Log
LOGFILE="/dev/null"

source /opt/outsystems/platform/common.sh

function getProperty(){

    local RESULT=$(grep -i $@ $OUTSYSTEMS_HOME/server.hsconf | cut -d ">" -f 2 | cut -d "<" -f 1 2>/dev/null)
    echo "getProperty $@ = $RESULT" >> $LOGFILE
    echo $RESULT
}

function performValidations(){
    if [ "$WL_DOMAIN" == "" ]
    then
        log_warning_msg "Environment Variable missing: WL_DOMAIN"
        log_end_msg 1
        exit 1
    fi
}

function isAdminServer(){
	chkconfig --list "weblogic-outsystems-adminserver" 2>/dev/null | grep :on 1>/dev/null
}

function isNodeManager(){
	chkconfig --list "weblogic-outsystems-nodemanager" 2>/dev/null | grep :on 1>/dev/null
}

function getNodeManagerPID(){
    NODEMANAGER_PID=$(pgrep -u $(getWeblogicOutSystemsUser) -f "weblogic.NodeManager")
    echo "NODEMANAGER_PID=$NODEMANAGER_PID" >> $LOGFILE
    echo $NODEMANAGER_PID
}

function getWeblogicOutSystemsUser(){

    #WL_DOMAIN owner will be the user used to start | stop the WebLogic services
    WL_OSUSER=$(stat -c %U $WL_DOMAIN)

    if [ "$WL_OSUSER" == "" ]
    then
        log_daemon_msg "WebLogic OutSystems user not found"
        log_end_msg 1
        exit 1
    fi

    echo $WL_OSUSER
}

function getWeblogicOutSystemsGroup(){

    WL_OSUSER=$(stat -c %G $WL_DOMAIN)

    if [ "$WL_OSUSER" == "" ]
    then
        log_daemon_msg "WebLogic OutSystems group not found"
        log_end_msg 1
        exit 1
    fi

    echo $WL_OSUSER
}

function getWebLogicConsoleHost(){
    getProperty OutSystems.Weblogic.ConsoleHost
}

function getWebLogicConsolePort(){
    getProperty OutSystems.Weblogic.ConsolePort
}

function getWeblogicAdminConsoleProtocolInUse(){
    getProperty OutSystems.Weblogic.ProtocolInUse
}

function getWeblogicAdminConsoleUser(){
    getProperty OutSystems.Weblogic.ConsoleUsername
}

function getWeblogicAdminConsolePassword(){
    getProperty OutSystems.Weblogic.ConsolePassword
}

function getOutSystemsServerName(){
    getProperty OutSystems.Weblogic.ServerTarget
}


function runJMX(){
	local USER=$(getWeblogicOutSystemsUser)
	
	local VARS=""
	# These vars are required in order to properly validate if AdminServer is started on first install
	if [ "$1" == "wait" -a "$wlsHostname" != "" -a "$wlsPort" != "" -a "$wlsProtocol" != "" -a "$wlsUserID" != "" -a "$wlsPassword" != "" ]
	then
		VARS="wlsHostname=\"$wlsHostname\" wlsPort=\"$wlsPort\" wlsProtocol=\"$wlsProtocol\" wlsUserID=\"$wlsUserID\" wlsPassword=\"$wlsPassword\""
	fi

	local COMMAND="$VARS $JAVA_HOME/bin/java -classpath $OUTSYSTEMS_HOME/lib/*:$OUTSYSTEMS_HOME/outsystems.hubedition.runtimeplatformutil.jar:$OUTSYSTEMS_HOME/outsystems.hubedition.runtimecommon.jar:$OUTSYSTEMS_HOME/outsystems.hubedition.common.jar:$OUTSYSTEMS_HOME/outsystems.hubedition.runtimeplatform.jar:$OUTSYSTEMS_HOME/outsystems.hubedition.databaseabstractionlayer.jar:$OUTSYSTEMS_HOME/plugins/database/*:$OUTSYSTEMS_HOME/outsystems.hubedition.servercommon.jar:$OUTSYSTEMS_HOME/outsystems.runtimeservices.jar:$OUTSYSTEMS_HOME/lib/active.connectors/*:$OUTSYSTEMS_HOME/deployservice.jar outsystems.connector.weblogic.WebLogicServices $1"

	if [ -z "$2" ]
	then
		# log to file
		runCommandAsUser "$USER" "$COMMAND" >>$LOGFILE 2>&1
		echo "$?"
	else
		# show output on screen
		runCommandAsUser "$USER" "$COMMAND"
	fi
}

function activateLog(){
    LOGFILE="$OUTSYSTEMS_HOME/logs/weblogic-outsystems.log" ;
    if [ ! -f $LOGFILE ]
    then
        touch $LOGFILE
    fi
    chown $(getWeblogicOutSystemsUser)":"$(getWeblogicOutSystemsGroup) $LOGFILE
}

#activateLog


